@@ -38,6 +38,7 @@
 #include "nautilus-vfs-directory.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 enum {
@@ -453,19 +454,31 @@ nautilus_directory_get_existing_corresponding_file (NautilusDirectory *directory
 char *
 nautilus_directory_get_name_for_self_as_new_file (NautilusDirectory *directory)
 {
+	GFile *file;
 	char *directory_uri;
-	char *name, *colon;
-	
-	directory_uri = nautilus_directory_get_uri (directory);
+	char *scheme;
+	char *name;
+	char *hostname = NULL;
 
-	colon = strchr (directory_uri, ':');
-	if (colon == NULL || colon == directory_uri) {
+	directory_uri = nautilus_directory_get_uri (directory);
+	file = g_file_new_for_uri (directory_uri);
+	scheme = g_file_get_uri_scheme (file);
+	g_object_unref (file);
+
+	nautilus_uri_parse (directory_uri, &hostname, NULL, NULL);
+	if (hostname == NULL || (strlen (hostname) == 0)) {
 		name = g_strdup (directory_uri);
+	} else if (scheme == NULL) {
+		name = g_strdup (hostname);
 	} else {
-		name = g_strndup (directory_uri, colon - directory_uri);
+		/* Translators: this is of the format "hostname (uri-scheme)" */
+		name = g_strdup_printf (_("%s (%s)"), hostname, scheme);
 	}
+
 	g_free (directory_uri);
-	
+	g_free (scheme);
+	g_free (hostname);
+
 	return name;
 }
 
@@ -547,6 +560,19 @@ nautilus_directory_is_in_recent (NautilusDirectory *directory)
 	return g_file_has_uri_scheme (directory->details->location, "recent");
 }
 
+gboolean
+nautilus_directory_is_in_network (NautilusDirectory *directory)
+{
+	g_assert (NAUTILUS_IS_DIRECTORY (directory));
+
+	if (directory->details->location == NULL) {
+		return FALSE;
+	}
+
+	return g_file_has_uri_scheme (directory->details->location, "network") ||
+		g_file_has_uri_scheme (directory->details->location, "dns-sd");
+}
+
 gboolean
 nautilus_directory_are_all_files_seen (NautilusDirectory *directory)
 {
