@@ -93,6 +93,8 @@ static time_t desktop_dir_modify_time;
 
 #define get_canvas_container(w) nautilus_canvas_view_get_canvas_container(NAUTILUS_CANVAS_VIEW (w))
 
+#define POPUP_PATH_CANVAS_APPEARANCE		"/selection/Canvas Appearance Items"
+
 static void
 canvas_container_set_workarea (NautilusCanvasContainer *canvas_container,
 			     GdkScreen             *screen,
@@ -648,6 +650,28 @@ action_empty_trash_conditional_callback (GtkAction *action,
 	nautilus_file_operations_empty_trash (GTK_WIDGET (data));
 }
 
+static void
+action_stretch_callback (GtkAction *action,
+			 gpointer callback_data)
+{
+	nautilus_canvas_container_show_stretch_handles
+		(get_canvas_container (callback_data));
+}
+
+static void
+action_unstretch_callback (GtkAction *action,
+			   gpointer callback_data)
+{
+	nautilus_canvas_container_unstretch (get_canvas_container (callback_data));
+}
+
+static void
+action_clean_up_callback (GtkAction *action,
+			  gpointer callback_data)
+{
+	nautilus_canvas_view_clean_up_by_name (NAUTILUS_CANVAS_VIEW (callback_data));
+}
+
 static gboolean
 trash_link_is_selection (NautilusView *view)
 {
@@ -681,9 +705,11 @@ static void
 real_update_menus (NautilusView *view)
 {
 	NautilusDesktopCanvasView *desktop_view;
-	char *label;
+        NautilusCanvasContainer *canvas_container;
 	gboolean include_empty_trash;
+	char *label;
 	GtkAction *action;
+        int selection_count;
 
 	g_assert (NAUTILUS_IS_DESKTOP_CANVAS_VIEW (view));
 
@@ -704,6 +730,31 @@ real_update_menus (NautilusView *view)
 					  !nautilus_trash_monitor_is_empty ());
 		g_free (label);
 	}
+
+	/* Stretch */
+        selection_count = nautilus_view_get_selection_count (view);
+        canvas_container = get_canvas_container (desktop_view);
+
+	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
+					      NAUTILUS_ACTION_STRETCH);
+	gtk_action_set_sensitive (action,
+				  selection_count == 1
+				  && canvas_container != NULL
+				  && !nautilus_canvas_container_has_stretch_handles (canvas_container));
+	gtk_action_set_visible (action, TRUE);
+
+	/* Unstretch */
+	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
+					      NAUTILUS_ACTION_UNSTRETCH);
+	g_object_set (action, "label",
+		      (selection_count > 1)
+		      ? _("Restore Icons' Original Si_zes")
+		      : _("Restore Icon's Original Si_ze"),
+		      NULL);
+	gtk_action_set_sensitive (action,
+				  canvas_container != NULL
+				  && nautilus_canvas_container_is_stretched (canvas_container));
+	gtk_action_set_visible (action, TRUE);
 }
 
 static const GtkActionEntry desktop_view_entries[] = {
@@ -721,6 +772,27 @@ static const GtkActionEntry desktop_view_entries[] = {
 	  /* tooltip */
 	  N_("Delete all items in the Trash"),
 	  G_CALLBACK (action_empty_trash_conditional_callback) },
+	/* name, stock id */
+	{ NAUTILUS_ACTION_CLEAN_UP, NULL,
+	  /* label, accelerator */
+	  N_("_Organize Desktop by Name"), NULL,
+	  /* tooltip */
+	  N_("Reposition icons to better fit in the window and avoid overlapping"),
+	  G_CALLBACK (action_clean_up_callback) },
+	/* name, stock id */
+         { "Stretch", NULL,
+	   /* label, accelerator */
+	   N_("Resize Icon..."), NULL,
+	   /* tooltip */
+	   N_("Make the selected icons resizable"),
+	   G_CALLBACK (action_stretch_callback) },
+	/* name, stock id */
+	{ "Unstretch", NULL,
+	  /* label, accelerator */
+	  N_("Restore Icons' Original Si_zes"), NULL,
+	  /* tooltip */
+	  N_("Restore each selected icons to its original size"),
+	  G_CALLBACK (action_unstretch_callback) },
 };
 
 static void
@@ -748,6 +820,21 @@ real_merge_menus (NautilusView *view)
 
 	desktop_view->details->desktop_merge_id =
 		gtk_ui_manager_add_ui_from_resource (ui_manager, "/org/gnome/nautilus/nautilus-desktop-canvas-view-ui.xml", NULL);
+
+	gtk_ui_manager_add_ui (ui_manager,
+			       desktop_view->details->desktop_merge_id,
+			       POPUP_PATH_CANVAS_APPEARANCE,
+			       NAUTILUS_ACTION_STRETCH,
+			       NAUTILUS_ACTION_STRETCH,
+			       GTK_UI_MANAGER_MENUITEM,
+			       FALSE);
+	gtk_ui_manager_add_ui (ui_manager,
+			       desktop_view->details->desktop_merge_id,
+			       POPUP_PATH_CANVAS_APPEARANCE,
+			       NAUTILUS_ACTION_UNSTRETCH,
+			       NAUTILUS_ACTION_UNSTRETCH,
+			       GTK_UI_MANAGER_MENUITEM,
+			       FALSE);
 }
 
 static NautilusView *
