@@ -188,8 +188,6 @@ struct NautilusViewClass {
 	/* Return an array of locations of selected icons in their view. */
 	GArray * (* get_selected_icon_locations) (NautilusView *view);
 
-	guint    (* get_item_count)             (NautilusView *view);
-
         /* bump_zoom_level is a function pointer that subclasses must override
          * to change the zoom level of an object. */
         void    (* bump_zoom_level)      	(NautilusView *view,
@@ -307,7 +305,6 @@ struct NautilusViewClass {
 GType               nautilus_view_get_type                         (void);
 
 /* Functions callable from the user interface and elsewhere. */
-NautilusWindow     *nautilus_view_get_nautilus_window              (NautilusView  *view);
 NautilusWindowSlot *nautilus_view_get_nautilus_window_slot     (NautilusView  *view);
 char *              nautilus_view_get_uri                          (NautilusView  *view);
 
@@ -413,4 +410,6 @@ void              nautilus_view_pop_up_location_context_menu (NautilusView    *v
 void              nautilus_view_grab_focus                 (NautilusView      *view);
 void              nautilus_view_update_menus               (NautilusView      *view);
 
+gboolean          nautilus_view_get_show_hidden_files      (NautilusView      *view);
+
 #endif /* NAUTILUS_VIEW_H */
